From 1edc402dc0a1f44117b910e4a42c5f6e6bc6b27f Mon Sep 17 00:00:00 2001
From: Pierre-Louis Bossart <pierre-louis.bossart@intel.com>
Date: Thu, 29 Apr 2010 17:00:59 -0500
Subject: [PATCH] [hda] remove HDA interrupts when buffer is processed
 This patch assumes a timer is used to wake-up the system and refill buffers
 (as PulseAudio does)

---
 core/pcm_lib.c      |    2 ++
 pci/hda/hda_intel.c |   14 ++++++++++++++
 2 files changed, 16 insertions(+), 0 deletions(-)

diff --git a/core/pcm_lib.c b/core/pcm_lib.c
index a2ff861..d1d5f77 100644
--- a/core/pcm_lib.c
+++ b/core/pcm_lib.c
@@ -420,6 +420,7 @@ static int snd_pcm_update_hw_ptr0(struct snd_pcm_substream *substream,
 		hw_base = new_hw_ptr - (new_hw_ptr % runtime->buffer_size);
 	}
  no_jiffies_check:
+#if 0 // skip when interrupts are not enabled
 	if (delta > runtime->period_size + runtime->period_size / 2) {
 		hw_ptr_error(substream,
 			     "Lost interrupts? %s"
@@ -430,6 +431,7 @@ static int snd_pcm_update_hw_ptr0(struct snd_pcm_substream *substream,
 			     (long)new_hw_ptr,
 			     (long)old_hw_ptr);
 	}
+#endif
 
 	if (runtime->status->hw_ptr == new_hw_ptr)
 		return 0;
diff --git a/pci/hda/hda_intel.c b/pci/hda/hda_intel.c
index 8b6815d..c64106e 100644
--- a/pci/hda/hda_intel.c
+++ b/pci/hda/hda_intel.c
@@ -1158,6 +1158,11 @@ static int setup_bdle(struct snd_pcm_substream *substream,
 {
 	u32 *bdl = *bdlp;
 
+#define NO_INTERRUPTS
+#ifdef  NO_INTERRUPTS
+    snd_printk(KERN_ERR SFX "plb- setup_bdle: interrupts disabled\n");
+#endif
+
 	while (size > 0) {
 		dma_addr_t addr;
 		int chunk;
@@ -1176,7 +1181,13 @@ static int setup_bdle(struct snd_pcm_substream *substream,
 		 * only when the whole fragment is processed
 		 */
 		size -= chunk;
+
+#ifdef NO_INTERRUPTS
+		bdl[3] = 0; /* no interrupts when buffer is processed */
+#else
 		bdl[3] = (size || !with_ioc) ? 0 : cpu_to_le32(0x01);
+#endif
+
 		bdl += 4;
 		azx_dev->frags++;
 		ofs += chunk;
@@ -1937,6 +1948,9 @@ static void azx_irq_pending_work(struct work_struct *work)
 			if (azx_position_ok(chip, azx_dev)) {
 				azx_dev->irq_pending = 0;
 				spin_unlock(&chip->reg_lock);
+#ifdef NO_INTERRUPTS
+				snd_printk(KERN_ERR SFX "plb- period elapsed: THIS SHOULD NOT HAPPEN \n");
+#endif
 				snd_pcm_period_elapsed(azx_dev->substream);
 				spin_lock(&chip->reg_lock);
 			} else
-- 
1.6.6.1

